@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-""" glogarchive v 0.3 (C) 2010 by Kurt Fleisch
+""" glogarchive v 0.5 (C) 2010 by Kurt Fleisch
     http://www.bananenfisch.net/n900/
 
     This program is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 
 import pygtk
 pygtk.require('2.0')
-import sys, os, shutil, sqlite3, time, gtk, hildon, cgi, csv
+import sys, os, shutil, sqlite3, time, gtk, hildon, cgi, csv, osso
 
 EL_PATH = "/home/user/.rtcom-eventlogger/el.db"
 ARCHIVE_PATH = "/home/user/.rtcom-eventlogger/el_archive.db"
@@ -31,95 +31,145 @@ class fenster:
         return False
 
     def show_about(self, widget):
-        about = gtk.AboutDialog()
-        about.set_name("glogarchive")
-        about.set_logo_icon_name("glogarchive")
-        about.set_comments("to archive SMS/IM messages and calling-history from the eventlogger to an extra DB")
-        about.set_version("0.3")
-        about.set_copyright("by Kurt Fleisch")
-        about.set_website("www.bananenfisch.net/n900")
-        about.run()
-        about.hide()
+        self.about = gtk.AboutDialog()
+        self.about.set_name("glogarchive")
+        self.about.set_logo_icon_name("glogarchive")
+        self.about.set_comments("to archive SMS/IM messages and calling-history from the eventlogger to an extra DB")
+        self.about.set_version("0.5")
+        self.about.set_copyright("by Kurt Fleisch")
+        gtk.about_dialog_set_url_hook(self.openurl, self.about)
+        self.about.set_website("www.bananenfisch.net/n900")
+        self.about.run()
+        self.about.hide()
+
+    def show_donate(self, widget):
+        self.donate = gtk.Dialog("Donate")
+        label = gtk.Label("If you like this Software and also want to be a helping hand,\nyou can donate via PayPal to:\n\nmarkus@bananenfisch.net")
+        label.set_justify(gtk.JUSTIFY_CENTER)
+        self.donate.vbox.pack_start(label, True, True, 5)
+        label.show()
+        gtk.link_button_set_uri_hook(self.openurl, self.donate)
+        linkbut = gtk.LinkButton("www.paypal.com/cgi-bin/webscr?cmd=_donations&business=markus%40bananenfisch%2enet&lc=AT&item_name=glogarchive&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted", "or use this link to go to PayPal directly")
+        self.donate.vbox.pack_start(linkbut, True, True, 5)
+        linkbut.show()
+        self.donate.run()
+        self.donate.hide()
+
+    def openurl(self, widget, url, dialogwidget):
+        self.osso_rpc.rpc_run_with_defaults("osso_browser", "open_new_window", (url,))
+        dialogwidget.destroy()
 
     def __init__(self):
+        self.archivedb = True
+        self.viewall = True
         self.window = hildon.StackableWindow()
         self.window.set_title("glogevent")
         self.window.connect("delete_event", self.close_application)
         self.window.set_border_width(0)
 
+        self.osso_c = osso.Context("glogarchive", "0.5", False)
+        self.osso_rpc = osso.Rpc(self.osso_c)
+
         gmenu = hildon.AppMenu()
-        butexport = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Export to CSV")
-        butexport.connect("clicked", export_csv)
-        gmenu.append(butexport)
-        butdrop = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Drop Archive")
-        butdrop.connect("clicked", drop_archive)
-        gmenu.append(butdrop)
 
         butabout = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "About")
         butabout.connect("clicked", self.show_about)
         gmenu.append(butabout)
+        butdonate = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Donate")
+        butdonate.connect("clicked", self.show_donate)
+        gmenu.append(butdonate)
+
+        butdrop = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Drop Archive")
+        butdrop.connect("clicked", drop_archive)
+        gmenu.append(butdrop)
         butquit = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Quit")
         butquit.connect("clicked", self.close_application)
         gmenu.append(butquit)
+
         gmenu.show_all()
         self.window.set_app_menu(gmenu)
 
+        columns = boxlines = gtk.HBox(False, 0)
+
         boxlines = gtk.VBox(False, 0)
-        line1 = gtk.HBox(True, 0)
-        butarch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "archive now!")
+
+        butarch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Archive new Events now!")
         butarch.connect("clicked", archive)
-        line1.pack_start(butarch, True, True, 0)
+        boxlines.pack_start(butarch, False, False, 0)
         butarch.show()
-        butsum = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "full stats")
-        butsum.connect("clicked", listall)
-        line1.pack_start(butsum, True, True, 0)
-        butsum.show()
-        line1.show()
-        boxlines.pack_start(line1, False, False, 0)
-
-        datebox = gtk.HBox(True, 0)
-        butfrom = hildon.DateButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        butfrom.set_text("from", "")
-        datebox.pack_start(butfrom, True, True, 0)
-        butfrom.show()
-        butto = hildon.DateButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        butto.set_text("to", "")
-        datebox.pack_start(butto, True, True, 0)
-        butto.show()
-        butdate = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "date stats")
-        butdate.connect("clicked", listall, butfrom, butto)
-        datebox.pack_start(butdate, True, True, 0)
-        butdate.show()
-        boxlines.pack_start(datebox, False, False, 0)
-        datebox.show()
-
-        line3 = gtk.HBox(True, 0)
-        butgrpnum = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "group by uid")
-        butgrpnum.connect("clicked", viewuid)
-        line3.pack_start(butgrpnum, True, True, 0)
-        butgrpnum.show()
-        butgrpevt = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "group by event")
-        butgrpevt.connect("clicked", viewevt)
-        line3.pack_start(butgrpevt, True, True, 0)
-        butgrpevt.show()
-        line3.show()
-        boxlines.pack_start(line3, False, False, 0)
-
-        boxlines.show()
-        self.window.add(boxlines)
 
         self.outlines = gtk.VBox(False, 0)
         scrolled_window = hildon.PannableArea()
         boxlines.pack_start(scrolled_window, True, True, 0)
         scrolled_window.show()
         scrolled_window.add_with_viewport(self.outlines)
-
         self.outlines.show()
+
+        datebox = gtk.HBox(False, 0)
+
+        self.butfrom = hildon.DateButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        self.butfrom.set_text("From", "")
+        self.butfrom.connect("value-changed", listall, True)
+        datebox.pack_start(self.butfrom, True, True, 0)
+        self.butfrom.show()
+
+        self.butto = hildon.DateButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        self.butto.set_text("To", "")
+        self.butto.connect("value-changed", listall, True)
+        datebox.pack_start(self.butto, True, True, 0)
+        self.butto.show()
+
+        butdate = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View All")
+        butdate.connect("clicked", listall)
+        datebox.pack_start(butdate, True, True, 0)
+        butdate.show()
+
+        boxlines.pack_start(datebox, False, False, 0)
+        datebox.show()
+
+        boxlines.show()
+
+        left = gtk.VBox(False, 5)
+
+        self.butcharch = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Switch to Live-Database")
+        self.butcharch.connect("clicked", change_db)
+        left.pack_start(self.butcharch, False, False, 0)
+        self.butcharch.show()
+        self.labdb = gtk.Label()
+        self.labdb.set_markup("You are viewing:\n<big><b><i>The Archive</i></b></big>")
+        self.labdb.set_justify(gtk.JUSTIFY_CENTER)
+        left.pack_start(self.labdb, False, False, 0)
+        self.labdb.show()
+
+        butgrpevt = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View Events by Type")
+        butgrpevt.connect("clicked", viewevt)
+        left.pack_end(butgrpevt, False, False, 0)
+        butgrpevt.show()
+        butgrpnum = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "View Events by User")
+        butgrpnum.connect("clicked", viewuid)
+        left.pack_end(butgrpnum, False, False, 0)
+        butgrpnum.show()
+        butcsv = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Export to CSV-File")
+        butcsv.connect("clicked", export_csv)
+        left.pack_end(butcsv, False, False, 0)
+        butcsv.show()
+
+        left.show()
+
+        separator = gtk.VSeparator()
+        separator.show()
+
+        columns.pack_start(left, True, True, 0)
+        columns.pack_start(separator, False, False, 4)
+        columns.pack_start(boxlines, True, True, 0)
+        columns.show()
+        self.window.add(columns)
+
         self.window.show()
 
 def archive(widget):
   for child in ui.outlines.get_children()[:]: ui.outlines.remove(child) # child.destroy()
-  label = gtk.Label("archive...")
+  label = gtk.Label("archiving, please wait...")
   label.set_alignment(0, 0)
   ui.outlines.pack_start(label, False, False, 0)
   label.show()
@@ -176,48 +226,69 @@ def archive(widget):
     label.set_alignment(0, 0)
     ui.outlines.pack_start(label, False, False, 0)
     label.show()
-    hildon.hildon_banner_show_information(ui.window, "", "done")
+    hildon.hildon_banner_show_information(ui.window, "", "Done")
 
   else:
     print("Unable to open eventlogger file")
     sys.exit(1)
 
-def listall(widget, a = None, b = None):
+def listall(widget, filter = False):
   for child in ui.outlines.get_children()[:]: ui.outlines.remove(child) # child.destroy()
-  label = gtk.Label("Summary")
-  label.set_alignment(0, 0)
+  label = gtk.Label()
+  label.set_markup("<i>Summary</i>")
+  label.set_justify(gtk.JUSTIFY_CENTER)
   ui.outlines.pack_start(label, False, False, 0)
   label.show()
-  if os.path.isfile(ARCHIVE_PATH):
-    conn = sqlite3.connect(ARCHIVE_PATH)
+
+  if ui.archivedb == True:
+    pfad = ARCHIVE_PATH
+  else:
+    pfad = EL_PATH
+
+  if os.path.isfile(pfad):
+    conn = sqlite3.connect(pfad)
     cur = conn.cursor()
-    if a == None or b == None:
-      cur.execute("select eventtypes.name, count(events.id) from events LEFT JOIN eventtypes ON events.event_type_id = eventtypes.id group by events.event_type_id")
+    if filter == False:
+      cur.execute("select eventtypes.name, count(events.id) from eventtypes LEFT JOIN events ON events.event_type_id = eventtypes.id group by eventtypes.id order by eventtypes.id")
+      ui.viewall = True
     else:
-      (ayear, amonth, aday) = a.get_date()
-      (byear, bmonth, bday) = b.get_date()
+      ui.viewall = False
+      (ayear, amonth, aday) = ui.butfrom.get_date()
+      (byear, bmonth, bday) = ui.butto.get_date()
       amonth = amonth+1
       bmonth = bmonth+1
       daten1 = "%d-%02d-%02d" % (ayear, amonth, aday)
       daten2 = "%d-%02d-%02d" % (byear, bmonth, bday)
       stampfrom = time.mktime(time.strptime(daten1, "%Y-%m-%d"))
       stampto = time.mktime(time.strptime(daten2+" 23:59:59", "%Y-%m-%d %H:%M:%S"))
-      cur.execute("select eventtypes.name, count(events.id) from events LEFT JOIN eventtypes ON events.event_type_id = eventtypes.id where events.start_time >= ? and events.start_time <= ? group by events.event_type_id", (stampfrom, stampto))
+      cur.execute("select eventtypes.name, count(events.id) from eventtypes LEFT JOIN events ON events.event_type_id = eventtypes.id where events.start_time >= ? and events.start_time <= ? group by eventtypes.id order by eventtypes.id", (stampfrom, stampto))
     for row in cur:
-      label = gtk.Label("%s: %d" % (gettype(row[0]), row[1]))
-      label.set_alignment(0, 0)
-      ui.outlines.pack_start(label, False, False, 0)
-      label.show()
+      sumzeile = gtk.HBox(False, 0)
+      label1 = gtk.Label("%s:" % (gettype(row[0])))
+      label1.set_alignment(0, 0)
+      label2 = gtk.Label("%d" % (row[1]))
+      label2.set_alignment(0, 0)
+      sumzeile.pack_start(label1, False, False, 50)
+      sumzeile.pack_end(label2, False, False, 50)
+      label1.show()
+      label2.show()
+      sumzeile.show()
+      ui.outlines.pack_start(sumzeile, False, False, 0)
     cur.close()
   else:
-    label = gtk.Label("Unable to open eventlogger-archive file\narchive first!")
-    label.set_alignment(0, 0)
+    label = gtk.Label("Unable to open Database!\nHit the Button above to archive")
+    label.set_justify(gtk.JUSTIFY_CENTER)
     ui.outlines.pack_start(label, False, False, 0)
     label.show()
-    hildon.hildon_banner_show_information(ui.window, "", "no archive found!")
+    hildon.hildon_banner_show_information(ui.window, "", "No Archive found!")
 
 def viewuid(widget):
-  if os.path.isfile(ARCHIVE_PATH):
+  if ui.archivedb == True:
+    pfad = ARCHIVE_PATH
+  else:
+    pfad = EL_PATH
+
+  if os.path.isfile(pfad):
     winuid = hildon.StackableWindow()
     winuid.set_title("glogevent: uid")
     winuid.set_border_width(0)
@@ -226,7 +297,7 @@ def viewuid(widget):
     winuid.add(scrolled_window)
     scrolled_window.add_with_viewport(gruppen)
 
-    conn = sqlite3.connect(ARCHIVE_PATH)
+    conn = sqlite3.connect(pfad)
     cur = conn.cursor()
     cur.execute("select count(Events.id), Events.start_time, Events.remote_uid, Remotes.remote_name, substr(Events.remote_uid, -7) as shortuid from Events left join Remotes on Events.remote_uid = Remotes.remote_uid group by shortuid order by Events.start_time desc")
     for row in cur:
@@ -250,14 +321,19 @@ def viewuid(widget):
     cur.close()
 
   else:
-    label = gtk.Label("Unable to open eventlogger-archive file\narchive first!")
-    label.set_alignment(0, 0)
+    label = gtk.Label("Unable to open Archive!\nHit the Button above to archive")
+    label.set_justify(gtk.JUSTIFY_CENTER)
     ui.outlines.pack_start(label, False, False, 0)
     label.show()
-    hildon.hildon_banner_show_information(ui.window, "", "no archive found!")
+    hildon.hildon_banner_show_information(ui.window, "", "No Archive found!")
 
 def viewevt(widget):
-  if os.path.isfile(ARCHIVE_PATH):
+  if ui.archivedb == True:
+    pfad = ARCHIVE_PATH
+  else:
+    pfad = EL_PATH
+
+  if os.path.isfile(pfad):
     winuid = hildon.StackableWindow()
     winuid.set_title("glogevent: event")
     winuid.set_border_width(0)
@@ -267,7 +343,7 @@ def viewevt(widget):
     winuid.add(scrolled_window)
     scrolled_window.add_with_viewport(gruppen)
 
-    conn = sqlite3.connect(ARCHIVE_PATH)
+    conn = sqlite3.connect(pfad)
     cur = conn.cursor()
     cur.execute("select id, name from EventTypes")
     for row in cur:
@@ -285,13 +361,18 @@ def viewevt(widget):
     cur.close()
 
   else:
-    label = gtk.Label("Unable to open eventlogger-archive file\narchive first!")
-    label.set_alignment(0, 0)
+    label = gtk.Label("Unable to open Archive!\nHit the Button above to archive")
+    label.set_justify(gtk.JUSTIFY_CENTER)
     ui.outlines.pack_start(label, False, False, 0)
     label.show()
-    hildon.hildon_banner_show_information(ui.window, "", "no archive found!")
+    hildon.hildon_banner_show_information(ui.window, "", "No Archive found!")
 
 def viewdetail(widget, did, viewtype):
+  if ui.archivedb == True:
+    pfad = ARCHIVE_PATH
+  else:
+    pfad = EL_PATH
+
   winuid = hildon.StackableWindow()
   winuid.set_title("glogevent: "+str(did))
   winuid.set_border_width(0)
@@ -301,7 +382,7 @@ def viewdetail(widget, did, viewtype):
   winuid.add(scrolled_window)
   scrolled_window.add_with_viewport(gruppen)
 
-  conn = sqlite3.connect(ARCHIVE_PATH)
+  conn = sqlite3.connect(pfad)
   cur = conn.cursor()
   if viewtype == "user":
     cur.execute("select Eventtypes.name, Events.start_time, Events.free_text, Events.remote_uid from Events left join Eventtypes on Events.event_type_id = Eventtypes.id where substr(Events.remote_uid, -7) = ? order by Events.start_time desc", (did,))
@@ -333,34 +414,55 @@ def viewdetail(widget, did, viewtype):
   cur.close()
 
 def export_csv(widget):
-  if os.path.isfile(ARCHIVE_PATH):  
+  if ui.archivedb == True:
+    pfad = ARCHIVE_PATH
+    prefix = "archive-"
+  else:
+    pfad = EL_PATH
+    prefix = "liveDB-"
+
+  if os.path.isfile(pfad):  
     exportdir = os.getenv("MYDOCSDIR")
     if exportdir == "": exportdir = os.getenv("HOME")
     now = time.strftime("%Y%m%d-%H%M%S")
-    savefile = exportdir + "/archive-" + now + ".csv"
+    savefile = exportdir + "/" + prefix + now + ".csv"
     csvfile = open(savefile, 'w')
-    conn = sqlite3.connect(ARCHIVE_PATH)
+    conn = sqlite3.connect(pfad)
     cur = conn.cursor()
     archcsv = csv.writer(csvfile, delimiter=';', quoting=csv.QUOTE_NONNUMERIC)
     archcsv.writerow(['ID', 'EventTypes.name', 'storage_time', 'start_time', 'end_time', 'is_read', 'flags', 'bytes_sent', 'bytes_received', 'local_uid', 'local_name', 'remote_uid', 'remote_name', 'channel', 'free_text', 'group_uid'])
     cur.execute("SELECT Events.id, EventTypes.name, Events.storage_time, Events.start_time, Events.end_time, Events.is_read, Events.flags, Events.bytes_sent, Events.bytes_received, Events.local_uid, Events.local_name, Events.remote_uid, Remotes.remote_name, Events.channel, Events.free_text, Events.group_uid FROM Events LEFT JOIN EventTypes ON Events.event_type_id = EventTypes.id LEFT JOIN Remotes ON Events.remote_uid = Remotes.remote_uid ORDER BY Events.start_time")
     for row in cur:
       archcsv.writerow(row)
-    hildon.hildon_banner_show_information(ui.window, "", "... saved to:\n"+savefile)
+    hildon.hildon_banner_show_information(ui.window, "", "File saved to:\n"+savefile)
     csvfile.close()
   else:
-    hildon.hildon_banner_show_information(ui.window, "", "no archive found!")
+    hildon.hildon_banner_show_information(ui.window, "", "No Archive found!")
 
 def drop_archive(widget):
-  note = hildon.Note("confirmation", ui.window, "are you sure to delete the archive?")
+  note = hildon.Note("confirmation", ui.window, "Are you sure to delete the archive?")
   retcode = gtk.Dialog.run(note)
   note.destroy()
   if retcode == gtk.RESPONSE_OK:
     if os.path.isfile(ARCHIVE_PATH):
       os.remove(ARCHIVE_PATH)
-      hildon.hildon_banner_show_information(ui.window, "", "done")
+      hildon.hildon_banner_show_information(ui.window, "", "Done")
     else:
-      hildon.hildon_banner_show_information(ui.window, "", "no archive found")
+      hildon.hildon_banner_show_information(ui.window, "", "No Archive found")
+
+def change_db(widget):
+  if ui.archivedb == True:
+    ui.archivedb = False
+    ui.labdb.set_markup("You are viewing:\n<big><b><i>The Live-Eventlogger</i></b></big>")
+    ui.butcharch.set_label("Switch to Archive")
+  else:
+    ui.archivedb = True
+    ui.labdb.set_markup("You are viewing:\n<big><b><i>The Archive</i></b></big>")
+    ui.butcharch.set_label("Switch to Live-Database")
+  if ui.viewall == True:
+    listall(ui)
+  else:
+    listall(ui, True)
 
 def gettype(typename):
   if typename == "RTCOM_EL_EVENTTYPE_CALL_INBOUND": return "in CALL"
@@ -375,4 +477,5 @@ def gettype(typename):
 
 if __name__ == "__main__":
   ui = fenster()
+  listall(ui)
   gtk.main()
